@@ -1305,6 +1305,7 @@ HyperWidget w;
     if(w->hyper.grep_seg)
     {
         text_segment *s = w->hyper.grep_seg;
+        char *p = s->text;
         XCharStruct   char_info;
         int dir,ascent,desc;
 
@@ -1383,7 +1384,7 @@ HyperWidget w;
 static char *loc1,*loc2;
 static int len;
 
-static void compile(w,buf,end)
+static compile(w,buf,end)
 char *w,*buf;
 int end;
 {
@@ -1391,7 +1392,7 @@ int end;
     len = strlen(w);
 }
 
-static int step(w,buf)
+static step(w,buf)
 char *w;
 char *buf;
 {
@@ -1443,11 +1444,11 @@ Boolean HyperGrep(HyperWidget widget,
 {
     char         *w = word;
     char         *p;
-    int          offset;
+    int          offset,from,to;
     text_segment *s;
     char          expbuf[ESIZE];
 
-    if(!widget->hyper.first_seg) return FALSE;
+    if(!widget->hyper.first_seg) return;
 
     if(ignore_case)
     {
